shill: Rename SMLOG to SLOG

Rewrite SMLOG as SLOG, thus saving many edits.  Change the location of
the SLOG macro to be memory_log.h, requiring includes to be rewritten
and reordered.  While we're rewriting includes, moving all assorted
logging includes into a generic shill/logging.h, thus saving future
logging changes from altering these includes ever again.

BUG=chromium-os:31145
TEST=Builds, unit tests still pass

Change-Id: Ie5129fcbdda87f3149460209a682c698b876b09a
Reviewed-on: https://gerrit.chromium.org/gerrit/29650
Commit-Ready: Christopher Wiley <wiley@chromium.org>
Reviewed-by: Christopher Wiley <wiley@chromium.org>
Tested-by: Christopher Wiley <wiley@chromium.org>
diff --git a/memory_log_unittest.cc b/memory_log_unittest.cc
index 016c036..ae352c8 100644
--- a/memory_log_unittest.cc
+++ b/memory_log_unittest.cc
@@ -6,14 +6,12 @@
 #include <string>
 
 #include <base/file_util.h>
-#include <base/logging.h>
 #include <base/scoped_temp_dir.h>
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
 
-#include "shill/memory_log.h"
+#include "shill/logging.h"
 #include "shill/mock_log.h"
-#include "shill/scope_logger.h"
 
 using testing::_;
 
@@ -48,15 +46,15 @@
   ScopedMockLog log;
   EXPECT_CALL(log, Log(_, _, kTestStr1WithPrefix));
   EXPECT_CALL(log, Log(_, _, kTestStr2WithPrefix));
-  SMLOG(WiFi, 2) << "does not get through";
+  SLOG(WiFi, 2) << "does not get through";
   ScopeLogger::GetInstance()->EnableScopesByName("+wifi");
   // Verbose levels are inverted.
   ScopeLogger::GetInstance()->set_verbose_level(3);
-  SMLOG(WiFi, 2) << kTestStr1;
+  SLOG(WiFi, 2) << kTestStr1;
   // It would be nice if the compiler didn't optimize out my conditional check.
-  SMLOG_IF(WiFi, 3, strlen("two") == 3) << kTestStr2;
-  SMLOG_IF(WiFi, 3, strlen("one") == 2) << "does not get through again";
-  SMLOG(WiFi, 4) << "spanish inquisition";
+  SLOG_IF(WiFi, 3, strlen("two") == 3) << kTestStr2;
+  SLOG_IF(WiFi, 3, strlen("one") == 2) << "does not get through again";
+  SLOG(WiFi, 4) << "spanish inquisition";
 }
 
 TEST_F(MemoryLogTest, NormalLoggingStillWorks) {
@@ -151,10 +149,10 @@
   // Make sure we're not double logging.
   MLOG(ERROR) << kTestStr1;
   ASSERT_EQ(2, MemoryLog::GetInstance()->TestGetNumberMessages());
-  // SMLOG_IF works with the intercepting handler.
-  SMLOG_IF(WiFi, 3, strlen("two") == 3) << kTestStr2;
+  // SLOG_IF works with the intercepting handler.
+  SLOG_IF(WiFi, 3, strlen("two") == 3) << kTestStr2;
   ASSERT_EQ(3, MemoryLog::GetInstance()->TestGetNumberMessages());
-  SMLOG_IF(WiFi, 3, strlen("one") == 2) << "does not get through again";
+  SLOG_IF(WiFi, 3, strlen("one") == 2) << "does not get through again";
   ASSERT_EQ(3, MemoryLog::GetInstance()->TestGetNumberMessages());
   // Similarly, MLOG_IF works with the handler.
   MLOG_IF(ERROR, strlen("two") == 3) << kTestStr2;